import os


    
class MDLOG:
    EXT = '.md'
    PNG = '.png'
    
    def __init__(self, base_dir, file_name, sep=' ', end='\n\n'):
        self.sep=sep
        self.end=end
        os.makedirs(base_dir, exist_ok=True)
        self.folder = base_dir
        if not file_name.endswith(MDLOG.EXT):
            file_name = file_name + MDLOG.EXT
        self.file = file_name
        self.path = os.path.join(base_dir, file_name)
        print('[MDLOG]@:', self.path)
        
    def open(self):
        self.f = open(self.path, 'w')
        return
    
    def close(self):
        self.f.close()
        return
            
    def log(self, *msg):
        for m in msg:
            self.f.write(str(m))

    def head(self, h, msg):
        h = min(max(h,1),6)
        self.nl()
        for i in range(h):
            self.log('#')
        self.log(' ', msg, '\n\n')
        
            
    def print(self, *msg):
        for m in msg:
            self.f.write(str(m)+self.sep)
        self.f.write(self.end)
            
    def nl(self):
        self.f.write('\n')
        
        
    def fig(self, figure, file_name):
        if not file_name.endswith(MDLOG.PNG):
            file_name = file_name + MDLOG.PNG
        file_path = os.path.join(self.folder, file_name)
        figure.savefig(file_path)
        self.log('![',file_name,']','(' , file_name ,')\n')
        self.nl()
        
    def table(self, header, A):
        h="|"
        for i in header:
            h+=str(i) + "|"
        self.log(h)
        self.nl()
        
        h="|"
        for i in header:
            h+=  "---|"
        self.log(h)
        self.nl()
        rows = len(A)
        for i in range(rows):
            h='|'
            cols = len(A[i])
            for j in range(cols):
                h +=str(A[i][j]) + '|'
            self.log(h)
            self.nl()
        self.nl()

    
    def dic(self, D):
        self.log("| Key | Value | \n| --- | --- | \n")
        for k in D:
            self.log('| '+str(k)+' | '+str(D[k]) + ' | \n')
        self.nl()

    def sdic(self, kv, caption=""):
        self.log('<pre>\n')
        self.log("=-=-=-=-==-=-=-=-=\nDICT: "+caption+"\n=-=-=-=-==-=-=-=-=\n")
        for i in kv:
            self.log(str(i) + " : " + str(kv[i]), '\n')
        self.log("=-=-=-=-==-=-=-=-=\n")
        self.log('</pre>\n\n')

    def lis(self, L, level, cont=False):
        lstr = ""
        for i in range(level):
            lstr+='\t'
        for i in L:
            self.log(lstr, '* ', i, '\n')
        if not cont:
            self.nl()
        